spoon.transports.transports.SpoonRPCHello

Package spoon :: Package transports :: Module transports :: Class SpoonRPCHello |
[hide private]
[frames] | no frames]

# Class SpoonRPCHello

source code

    object --+
             |
        Serial --+
                 |
                SpoonRPCHello

This object is sent as a very simple form of initial negotiation. It contains the nodeId and the protocol version (currently always 1.)

Nested Classes | [hide private]
Inherited from `Serial`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `Serial`: `decode_lazy`, `post_deserialize`, `pre_serialize` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__init__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Static Methods | [hide private]
Inherited from `Serial`: `__new__`

Class Variables | [hide private]
`` | nodeId = `<spoon.serialprop object at 0xa79e2d0c>`
`` | version = `<spoon.serialprop object at 0xa79e2d8c>`
`` | _spoon_attrs = `['version', 'nodeId']`

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

    ### nodeId None Value:
        <spoon.serialprop object at 0xa79e2d0c>

    ### version None Value:
        <spoon.serialprop object at 0xa79e2d8c>

    ### _spoon_attrs None Value:
        ['version', 'nodeId']